@@ -22,42 +22,42 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
     def test_script_task(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/script_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/script_task.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"n": 8})
         self.assertEqual(state["test"], 21)
 
     def test_exclusive_gateway(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/exclusive_gateway.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/exclusive_gateway.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"flag": True})
         self.assertEqual(state["result"], 10)
 
     def test_exclusive_gateway_with_default(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/exclusive_gateway_with_default.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/exclusive_gateway_with_default.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"flag": False})
         self.assertEqual(state["result"], 20)
 
     def test_message_start_event(self):
         engine = SequentialBpmnEngine()
-        _ = engine.deploy(Path(__file__).parent / "diagrams/message_start_event.bpmn")[0]
+        _ = engine.deploy("customGroup", Path(__file__).parent / "diagrams/message_start_event.bpmn")[0]
 
         state = engine.invoke_by_event(MessageEvent("customGroup", "custom-message"))[0]
         self.assertEqual(state["test"], True)
 
     def test_signal_start_event(self):
         engine = SequentialBpmnEngine()
-        _ = engine.deploy(Path(__file__).parent / "diagrams/signal_start_event.bpmn")[0]
+        _ = engine.deploy("customGroup", Path(__file__).parent / "diagrams/signal_start_event.bpmn")[0]
 
         state = engine.invoke_by_event(SignalEvent("customGroup", "custom-signal"))[0]
         self.assertEqual(state["test"], True)
 
     def test_call_activity(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/call_activity.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/call_activity.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"x": 5})
         self.assertAlmostEqual(state["y1"], 7.5)
@@ -65,14 +65,14 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
     def test_error_boundary_event(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/error_boundary_event.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/error_boundary_event.bpmn")[0]
 
         engine.invoke_by_id(ref, {"x": 5})
 
     # noinspection PyUnresolvedReferences
     def test_message_intermediate_throw_event(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/message_intermediate_throw_event.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/message_intermediate_throw_event.bpmn")[0]
 
         engine.invoke_by_id(ref, {"x": 5})
         self.assertEqual(len(engine.event_emitter.bucket), 1)
@@ -80,7 +80,7 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
     def test_message_intermediate_catch_event(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/message_intermediate_catch_event.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/message_intermediate_catch_event.bpmn")[0]
 
         engine.invoke_by_id(ref)
         engine.invoke_by_event(MessageEvent("customGroup", "custom-message"))
@@ -88,7 +88,7 @@ class SequentialBpmnEngineTest(unittest.TestCase):
     # noinspection PyUnresolvedReferences
     def test_signal_intermediate_throw_event(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/signal_intermediate_throw_event.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/signal_intermediate_throw_event.bpmn")[0]
 
         engine.invoke_by_id(ref, {"x": 5})
         self.assertEqual(len(engine.event_emitter.bucket), 1)
@@ -96,21 +96,21 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
     def test_signal_intermediate_catch_event(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/signal_intermediate_catch_event.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/signal_intermediate_catch_event.bpmn")[0]
 
         engine.invoke_by_id(ref)
         engine.invoke_by_event(SignalEvent("customGroup", "custom-signal"))
 
     def test_user_task(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/user_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/user_task.bpmn")[0]
 
         engine.invoke_by_id(ref)
         engine.invoke_by_event(UserEvent("customGroup", "Process_0elkd69", "task", {}))
 
     def test_manual_task(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/manual_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/manual_task.bpmn")[0]
 
         engine.invoke_by_id(ref)
         engine.invoke_by_event(ManualEvent("customGroup", "Process_0elkd69", "task", {}))
@@ -118,7 +118,7 @@ class SequentialBpmnEngineTest(unittest.TestCase):
     # noinspection PyUnresolvedReferences
     def test_send_task(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/send_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/send_task.bpmn")[0]
 
         engine.invoke_by_id(ref, {"x": 5})
         self.assertEqual(len(engine.event_emitter.bucket), 1)
@@ -126,7 +126,7 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
     def test_receive_task(self):
         engine = SequentialBpmnEngine(event_emitter=BucketEventEmitter())
-        ref = engine.deploy(Path(__file__).parent / "diagrams/receive_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/receive_task.bpmn")[0]
 
         engine.invoke_by_id(ref)
         engine.invoke_by_event(MessageEvent("customGroup", "custom-message"))
@@ -141,7 +141,7 @@ class SequentialBpmnEngineTest(unittest.TestCase):
 
         service_factory = LambdaServiceFactory(lambda x, y: ServiceDelegate())
         engine = SequentialBpmnEngine(parser=XmlBpmnParser(), service_factory=service_factory)
-        ref = engine.deploy(Path(__file__).parent / "diagrams/service_task.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/service_task.bpmn")[0]
 
         state = engine.invoke_by_id(ref)
         self.assertEqual(state["custom"], "test")
\ No newline at end of file
