@@ -14,16 +14,16 @@ class State:
     reference: NodeRef
     is_reentry: bool = False
     parent_reference: Optional[NodeRef] = None
-    headers: dict = field(default_factory=lambda: {})
+    header: dict = field(default_factory=lambda: {})
 
     def with_is_reentry(self, is_reentry: bool):
-        return State(self.properties, self.reference, is_reentry, self.parent_reference, self.headers)
+        return State(self.properties, self.reference, is_reentry, self.parent_reference, self.header)
 
     def with_parent_reference(self, parent_reference: Optional[NodeRef]):
-        return State(self.properties, self.reference, self.is_reentry, parent_reference, self.headers)
+        return State(self.properties, self.reference, self.is_reentry, parent_reference, self.header)
 
     def with_reference(self, reference: NodeRef):
-        return State(self.properties, reference, self.is_reentry, self.parent_reference, self.headers)
+        return State(self.properties, reference, self.is_reentry, self.parent_reference, self.header)
 
     def __setitem__(self, key, value):
         self.properties[key] = value
