@@ -28,13 +28,13 @@ def first(iterable):
 
 class SequentialBpmnEngine(BpmnEngine):
 
-    def invoke_by_event(self, event: Event, init_state: OptDict = None, headers: OptDict = None) -> List[State]:
+    def invoke_by_event(self, event: Event, init_state: OptDict = None, header: OptDict = None) -> List[State]:
         def invoke(subscription: NodeRef):
             process = self.process_store.read_process(ProcessRef(event.group, subscription.process_id))
             environment = Environment(event.group, process, self.factories)
 
             is_reentry = not environment.is_start_event(subscription.node_id)
-            state = State(init_state or {}, subscription, is_reentry, headers=headers)
+            state = State(init_state or {}, subscription, is_reentry, header=header)
 
             result = self._handle_action(ContinueAction(subscription.node_id), state, environment)
             return result[0]
@@ -43,9 +43,11 @@ class SequentialBpmnEngine(BpmnEngine):
         assert len(subscriptions) > 0, "no subscriptions found"
         return list(map(invoke, subscriptions))
 
-    def resume_by_event(self, event: Event) -> List[State]:
+    def resume_by_event(self, event: Event, init_state: OptDict = None) -> List[State]:
         def resume_process(node_ref: NodeRef) -> List[State]:
             state = self.process_store.read_state(node_ref)
+            state.properties.update(init_state or {})
+
             process = self.process_store.read_process(ProcessRef(event.group, node_ref.process_id))
             environment = Environment(event.group, process, self.factories)
 
@@ -55,8 +57,8 @@ class SequentialBpmnEngine(BpmnEngine):
         node_refs = self.event_registry.get_subscriptions(event)
         return flatten([resume_process(node_ref) for node_ref in node_refs])
 
-    def invoke_by_id(self, ref: ProcessRef, init_state: OptDict = None, headers: OptDict = None) -> State:
-        return self.invoke_by_event(NoneEvent(ref.group, ref.process_id), init_state, headers)[0]
+    def invoke_by_id(self, ref: ProcessRef, init_state: OptDict = None, header: OptDict = None) -> State:
+        return self.invoke_by_event(NoneEvent(ref.group, ref.process_id), init_state, header)[0]
 
     def _handle_action(self, action: Action, state: State, env: Environment) -> List[State]:
         logging.info(action)
