@@ -5,31 +5,19 @@ from arrow_bpmn.__spi__.action import Actions, ContinueAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.__spi__.factory.business_rule_factory import BusinessRuleFactory
-from arrow_bpmn.parser.json.json_element import JSONElement
-from arrow_bpmn.parser.xml.xml_element import XMLElement
+from arrow_bpmn.__spi__.registry.process_ref import ProcessRef
 
 
 class BusinessRuleTask(BpmnNode):
 
-    def __init__(self, attributes: dict, implementation: str):
-        super().__init__(attributes)
-        self.implementation = implementation
+    @property
+    def implementation(self):
+        return self._get_property("implementation")
 
     def with_business_rule_factory(self, factory: BusinessRuleFactory, environment: Environment):
         if isinstance(self.implementation, str):
-            self.implementation = factory.create(environment.group, self.implementation)
+            self.__dict__["implementation"] = factory(environment.group, self.implementation)
 
-    @staticmethod
-    def from_json(element: JSONElement) -> 'BusinessRuleTask':
-        implementation = element.pop("implementation")
-        return BusinessRuleTask(element.as_dict(), implementation)
-
-    @staticmethod
-    def from_xml(element: XMLElement) -> 'BusinessRuleTask':
-        implementation = element.get_attribute("implementation")
-        return BusinessRuleTask(element.get_attributes(), implementation)
-
-    # noinspection PyUnresolvedReferences
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         engine = environment.business_rule_factory(self.implementation)
         process_ref = ProcessRef(environment.group, self.implementation)
